==> centreon-web-23.10.24.tar.gz: centreon-web-23.10.24/src/Core/Dashboard/Domain/Model/Validation/DashboardValidationTrait.php <==
<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Dashboard\Domain\Model\Validation;

use Assert\AssertionFailedException;
use Centreon\Domain\Common\Assertion\Assertion;
use Core\Dashboard\Domain\Model\Dashboard;

/**
 * This trait exists only here for DRY reasons.
 *
 * It gathers all the guard methods of common fields from {@see Dashboard} and {@see NewDashboard} entities.
 */
trait DashboardValidationTrait
{
    /**
     * @param string $name
     *
     * @throws AssertionFailedException
     */
    private function ensureValidName(string $name): void
    {
        $shortName = (new \ReflectionClass($this))->getShortName();
        Assertion::maxLength($name, Dashboard::MAX_NAME_LENGTH, $shortName . '::name');
        Assertion::notEmptyString($name, $shortName . '::name');
    }

    /**
     * @param string $description
     *
     * @throws AssertionFailedException
     */
    private function ensureValidDescription(string $description): void
    {
        $shortName = (new \ReflectionClass($this))->getShortName();
        Assertion::maxLength($description, Dashboard::MAX_DESCRIPTION_LENGTH, $shortName . '::description');
    }

    /**
     * @param int $value
     * @param string $propertyName
     *
     * @throws AssertionFailedException
     */
    private function ensurePositiveInt(int $value, string $propertyName): void
    {
        $shortName = (new \ReflectionClass($this))->getShortName();
        Assertion::positiveInt($value, $shortName . '::' . $propertyName);
    }

    /**
     * @param ?int $value
     * @param string $propertyName
     *
     * @throws AssertionFailedException
     */
    private function ensureNullablePositiveInt(?int $value, string $propertyName): void
    {
        if (null !== $value) {
            $this->ensurePositiveInt($value, $propertyName);
        }
    }
}

==> centreon-web-24.10.13.tar.gz: centreon-web-24.10.13/src/Core/Dashboard/Domain/Model/Validation/DashboardValidationTrait.php <==
<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Dashboard\Domain\Model\Validation;

use Assert\AssertionFailedException;
use Centreon\Domain\Common\Assertion\Assertion;
use Core\Dashboard\Domain\Model\Dashboard;

/**
 * This trait exists only here for DRY reasons.
 *
 * It gathers all the guard methods of common fields from {@see Dashboard} and {@see NewDashboard} entities.
 */
trait DashboardValidationTrait
{
    /**
     * @param string $name
     *
     * @throws AssertionFailedException
     */
    private function ensureValidName(string $name): void
    {
        $shortName = (new \ReflectionClass($this))->getShortName();
        Assertion::maxLength($name, Dashboard::MAX_NAME_LENGTH, $shortName . '::name');
        Assertion::notEmptyString($name, $shortName . '::name');
    }

    /**
     * @param string $description
     *
     * @throws AssertionFailedException
     */
    private function ensureValidDescription(string $description): void
    {
        $shortName = (new \ReflectionClass($this))->getShortName();
        Assertion::minLength($description, Dashboard::MIN_DESCRIPTION_LENGTH, $shortName . '::description');
        Assertion::maxLength($description, Dashboard::MAX_DESCRIPTION_LENGTH, $shortName . '::description');
    }

    /**
     * @param int $value
     * @param string $propertyName
     *
     * @throws AssertionFailedException
     */
    private function ensurePositiveInt(int $value, string $propertyName): void
    {
        $shortName = (new \ReflectionClass($this))->getShortName();
        Assertion::positiveInt($value, $shortName . '::' . $propertyName);
    }

    /**
     * @param ?int $value
     * @param string $propertyName
     *
     * @throws AssertionFailedException
     */
    private function ensureNullablePositiveInt(?int $value, string $propertyName): void
    {
        if (null !== $value) {
            $this->ensurePositiveInt($value, $propertyName);
        }
    }
}
